@@ -25,15 +25,18 @@ or on the L<website|http://functional-perl.org/>.
 
 =cut
 
-
 package Chj::singlequote::t;
 
-use strict; use warnings; use warnings FATAL => 'uninitialized';
+use strict;
+use warnings;
+use warnings FATAL => 'uninitialized';
 
 use Chj::singlequote ":all";
 use Chj::TEST;
 
-TEST { with_maxlen 9, sub { singlequote "Darc's place" } }
-  "'Darc\\'s...'";
+TEST {
+    with_maxlen 9, sub { singlequote "Darc's place" }
+}
+"'Darc\\'s...'";
 
 1
